@@ -1,3 +1,4 @@
+from pathlib import Path
 from typing import Any, Dict, List, Optional
 
 from pydantic import BaseModel, Field
@@ -5,11 +6,35 @@ from pydantic import BaseModel, Field
 from python_on_whales.utils import all_fields_optional
 
 
+@all_fields_optional
+class ServicePlacement(BaseModel):
+    constraints: List[str]
+
+
+@all_fields_optional
+class ResourcesLimits(BaseModel):
+    cpus: float
+    memory: int
+
+
+@all_fields_optional
+class ResourcesReservation(BaseModel):
+    cpus: float
+    memory: int
+
+
+@all_fields_optional
+class ServiceResources(BaseModel):
+    limits: ResourcesLimits
+    reservations: ResourcesReservation
+
+
 @all_fields_optional
 class ServiceDeployConfig(BaseModel):
     labels: Dict[str, str]
-    resources: Any
-    placement: Any
+    resources: ServiceResources
+    placement: ServicePlacement
+    replicas: int
 
 
 @all_fields_optional
@@ -17,6 +42,27 @@ class DependencyCondition(BaseModel):
     condition: str
 
 
+@all_fields_optional
+class ComposeServiceBuild(BaseModel):
+    context: Path
+
+
+@all_fields_optional
+class ComposeServicePort(BaseModel):
+    mode: str
+    protocol: str
+    published: int
+    target: int
+
+
+@all_fields_optional
+class ComposeServiceVolume(BaseModel):
+    bind: dict
+    source: str
+    target: str
+    type: str
+
+
 @all_fields_optional
 class ComposeConfigService(BaseModel):
     deploy: ServiceDeployConfig
@@ -25,7 +71,7 @@ class ComposeConfigService(BaseModel):
     cpu_percent: float
     cpu_shares: int
     cpuset: str
-    build: Any
+    build: ComposeServiceBuild
     cap_add: List[str] = Field(default_factory=list)
     cap_drop: List[str] = Field(default_factory=list)
     cgroup_parent: str
@@ -38,6 +84,8 @@ class ComposeConfigService(BaseModel):
     environment: Dict[str, Optional[str]]
     entrypoint: List[str]
     image: str
+    ports: List[ComposeServicePort]
+    volumes: List[ComposeServiceVolume]
 
 
 @all_fields_optional
