@@ -1,5 +1,6 @@
 import os
 import subprocess
+from datetime import datetime, timedelta
 from pathlib import Path
 from queue import Queue
 from subprocess import PIPE, Popen
@@ -13,6 +14,8 @@ from python_on_whales.exceptions import (
     NoSuchContainer,
     NoSuchImage,
     NoSuchService,
+    NoSuchVolume,
+    NotASwarmManager,
 )
 
 PROJECT_ROOT = Path(__file__).parents[1]
@@ -121,6 +124,23 @@ def run(
                     completed_process.stdout,
                     completed_process.stderr,
                 )
+            if (
+                "this node is not a swarm manager"
+                in completed_process.stderr.decode().lower()
+            ):
+                raise NotASwarmManager(
+                    args,
+                    completed_process.returncode,
+                    completed_process.stdout,
+                    completed_process.stderr,
+                )
+            if "no such volume" in completed_process.stderr.decode().lower():
+                raise NoSuchVolume(
+                    args,
+                    completed_process.returncode,
+                    completed_process.stdout,
+                    completed_process.stderr,
+                )
 
         raise DockerException(
             args,
@@ -216,7 +236,7 @@ def read_env_file(env_file: Path) -> Dict[str, str]:
         if not line:
             continue
         line = line.strip()
-        key, value = line.split("=")
+        key, value = line.split("=", 1)
         result_dict[key] = value
     return result_dict
 
@@ -234,3 +254,17 @@ def all_fields_optional(cls):
         field.required = False
         field.allow_none = True
     return cls
+
+
+def format_time_arg(time_object):
+    if time_object is None:
+        return None
+    else:
+        return format_time_for_docker(time_object)
+
+
+def format_time_for_docker(time_object: Union[datetime, timedelta]) -> str:
+    if isinstance(time_object, datetime):
+        return time_object.strftime("%Y-%m-%dT%H:%M:%S")
+    elif isinstance(time_object, timedelta):
+        return f"{time_object.total_seconds()}s"
